#
# spec file for package sway
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define contribver 1.10

Name:           sway
Version:        1.10.1
Release:        8.1
Summary:        Window manager for Wayland compatible with i3
License:        MIT
Group:          System/GUI/Other
URL:            https://github.com/swaywm/sway
Source0:        https://github.com/swaywm/sway/releases/download/%{version}/%{name}-%{version}.tar.gz
Source1:        https://github.com/swaywm/sway/releases/download/%{version}/%{name}-%{version}.tar.gz.sig
Source2:        https://emersion.fr/.well-known/openpgpkey/hu/dj3498u4hyyarh35rkjfnghbjxug6b19#/%{name}.keyring
Source3:        sway-portals.conf
Source4:        https://github.com/OctopusET/sway-contrib/archive/refs/tags/%{contribver}-contrib.0.tar.gz#/sway-contrib-%{contribver}.tar.gz
Source5:        sway.rpmlintrc
BuildRequires:  gcc-c++
#BuildRequires:  libxslt-tools
BuildRequires:  libevdev-devel
BuildRequires:  fdupes
BuildRequires:  libpixman-1-0-devel
BuildRequires:  meson >= 0.60.0
BuildRequires:  pam-devel
BuildRequires:  pkgconfig
BuildRequires:  python3-i3ipc
BuildRequires:  scdoc >= 1.9.2
BuildRequires:  pkgconfig(cairo)
BuildRequires:  pkgconfig(dbus-1) >= 1.10
BuildRequires:  pkgconfig(gdk-pixbuf-2.0)
BuildRequires:  pkgconfig(json-c) >= 0.13
BuildRequires:  pkgconfig(libcap)
BuildRequires:  pkgconfig(libinput) >= 1.21.0
BuildRequires:  pkgconfig(libpcre2-8)
BuildRequires:  pkgconfig(pango)
BuildRequires:  pkgconfig(pangocairo)
BuildRequires:  pkgconfig(wayland-client)
BuildRequires:  pkgconfig(wayland-cursor)
BuildRequires:  pkgconfig(wayland-egl)
BuildRequires:  pkgconfig(wayland-protocols) >= 1.24
BuildRequires:  pkgconfig(wayland-server) >= 1.21.0
BuildRequires:  pkgconfig(wlroots-0.18)
BuildRequires:  pkgconfig(xkbcommon)
# WARNING: do not set this to versioned, as it breaks other branding providers
# such as openSUSEway (bsc#1222579)
Requires:       %{name}-branding
%if 0%{?suse_version}
# I definitely recommend Xwayland
Recommends:     xorg-x11-server-wayland
%endif
Recommends:     swaybar
Recommends:     swaynag
Recommends:     xdg-desktop-portal-wlr

# For file picker and other stuff and for the sway-portal.conf
Recommends:     xdg-desktop-portal-gtk

%description
Sway is a tiling Wayland compositor and a drop-in replacement for the i3
window manager for X11. It works with your existing i3 configuration and
supports most of i3's features, plus a few extras.

%package branding-upstream
Summary:        Upstream branding of %{name}
Group:          System/GUI/Other
Requires:       %{name} = %{version}
Supplements:    (%{name} and branding-upstream)
Conflicts:      %{name}-branding
Provides:       %{name}-branding = %{version}
BuildArch:      noarch
#BRAND: /etc/sway/config contains upstream config and brand

%description branding-upstream
This package provides the upstream look and feel for sway.

%package contrib
Summary:        Contributed scripts for %{name}
Version:        %{contribver}
Group:          System/GUI/Other
# autoname-workspaces & inactive-windows-transparency
Requires:       python3-i3ipc
# for grimshot
Requires:       grim
Requires:       jq
Requires:       slurp
Requires:       sway
Requires:       wl-clipboard
BuildArch:      noarch

%description contrib
Contributed scripts from %{name} package.

%package -n swaybar
Summary:        Bar program for %{name}
Group:          System/GUI/Other
Requires:       sway

%description -n swaybar
Bar program for %{name}.

%package -n swaynag
Summary:        Displays warning and error messages in %{name}
Group:          System/GUI/Other
Requires:       sway

%description -n swaynag
Displays warning and error messages in %{name}.

%prep
%autosetup -p1
mkdir -p contrib
tar xvf %{SOURCE4} --strip-components=1 -C contrib/
pushd contrib
rm -rf .github
find -type f -name "*.py" -execdir sed -i 's,#!/usr/bin/env python$,#!/usr/bin/python3,' {} \;
find -type f -name "*.py" -execdir sed -i 's,#!/usr/bin/env python3$,#!/usr/bin/python3,' {} \;
find -type f -name "grimpicker" -execdir sed -i 's,#!/usr/bin/env python3$,#!/usr/bin/python3,' {} \;
find -type f -name "*.py" -execdir sed -i 's,#!/usr/bin/python$,#!/usr/bin/python3,' {} \;
popd

%build
export CFLAGS="%{optflags}"
%meson \
%if 0%{?suse_version} < 1550
  -Dtray=disabled \
%endif
  -Dsd-bus-provider=libsystemd

%meson_build

%install
%meson_install

# contrib
install -Dpm 0644 -t %{buildroot}%{_mandir}/man1 contrib/grimshot/*.1
install -Dpm 0755 -t %{buildroot}%{_bindir} contrib/grimshot/grimshot

# Move over other contrib files to /usr/share/sway/contrib folder
mkdir -p %{buildroot}%{_datadir}/%{name}/
cp -r contrib %{buildroot}%{_datadir}/%{name}/contrib
find %{buildroot}%{_datadir}/%{name}/contrib -type f -exec "chmod 0644 {}" \;
# Remove it since it's installed in /usr/bin
rm -v %{buildroot}%{_datadir}/%{name}/contrib/grimshot/grimshot

# XDP >= 0.18.0 requires a portal for the environment and onwards
install -Dpm 0644 -t %{buildroot}%{_datadir}/xdg-desktop-portal/ %{SOURCE3}

%fdupes %{buildroot}%{_prefix}

%files
%license LICENSE
%doc README.md CONTRIBUTING.md
%{_bindir}/sway
%{_bindir}/swaymsg
%{_mandir}/man1/sway.1.gz
%{_mandir}/man1/swaymsg.1.gz
%{_mandir}/man5/sway-input.5.gz
%{_mandir}/man5/sway-output.5.gz
%{_mandir}/man5/sway.5.gz
%{_mandir}/man7/sway-ipc.7.gz
%{_datadir}/wayland-sessions/
%dir %{_datadir}/backgrounds
%{_datadir}/backgrounds/sway
%{_datadir}/bash-completion/completions/sway
%{_datadir}/bash-completion/completions/swaymsg
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/sway.fish
%{_datadir}/fish/vendor_completions.d/swaymsg.fish
%{_datadir}/zsh/site-functions/_sway
%{_datadir}/zsh/site-functions/_swaymsg
%dir %{_datadir}/xdg-desktop-portal
%{_datadir}/xdg-desktop-portal/sway-portals.conf

%files branding-upstream
%dir %{_sysconfdir}/sway
%config(noreplace) %{_sysconfdir}/sway/config

%files contrib
%license LICENSE
%{_bindir}/grimshot
%{_mandir}/man1/grimshot*
%dir %{_datadir}/sway
%dir %{_datadir}/sway/contrib
%{_datadir}/sway/contrib/*

%files -n swaybar
%{_bindir}/swaybar
%{_mandir}/man5/sway-bar.5.gz
%{_mandir}/man7/swaybar-protocol.7.gz
%{_datadir}/bash-completion/completions/swaybar

%files -n swaynag
%{_bindir}/swaynag
%{_datadir}/fish/vendor_completions.d/swaynag.fish
%{_mandir}/man1/swaynag.1.gz
%{_mandir}/man5/swaynag.5.gz

%changelog
* Thu Mar 20 2025 Shawn Dunn <sfalken@opensuse.org>
- Update to BuildRequires: pkgconfig(libpcre2-8)
* Tue Jan 28 2025 Michael Vetter <mvetter@suse.com>
- Update to 1.10.1:
  * container: Properly constrain title bar padding
  * swaybar: Handle opaque region properly
  * input/libinput: fix builtin device detection logic
  * Explain that the title bar always shows
  * swaybar: Emit property changes for SNI watcher
  * desktop/output: Store output config on request_state
  * desktop/output: Add missing output config allocation checks
  * config/output: Update output position in two passes
  * desktop/output: Clean up output state if build_state fails
  * desktop/output: Clear frame_pending even output is disabled
  * config: Force modeset before running deferred configs
  * ipc-server: Force modeset if needed after executing commands
  * desktop/output: Clear repaint timer earlier in destroy
  * swaynag: fix null dereference on scale change
  * release.sh: read meson-rewrite output from stdout
  * ipc-json: handle LIBINPUT_CONFIG_DRAG_LOCK_ENABLED_STICKY
  * config/output: don't hardcode DMA-BUF in search_render_format()
  * build: bump version to 1.10.1
  * layer_shell: cleanup new_popup listener when destroying node
  * config/output: don't leak background_fallback
  * desktop/transaction: clamp vertical border length to 0
  * config/output: skip format checks if all are supported
- Drop libinput-drag-lock-enabled-sticky-fix-condition.patch
  and libinput-drag-lock-enabled-sticky.patch
* Mon Dec 16 2024 Lukas Müller <expeehaa@outlook.com>
- Add libinput-drag-lock-enabled-sticky-fix-condition.patch.
* Sat Nov 30 2024 Soc Virnyl Estela <uncomfyhalomacro@opensuse.org>
- Update sway contrib to 1.10
  * add --wait to grimshot
  * add switch-top-level.py script
  * docs: Add README
  * contrib: add sway-session.target
  * Chore / Limit grimshot window grab
  * Add anything subject option to grimshot
  * Disable escape in firefox player
  * Add layout-per-window.py script
  * Fix linting error
  * Add savecopy command to grimshot
  * Update README.md
  * feature: added active vs inactive
  * Default layout
  * Bash completions for grimshot
  * feat(grimshot): show image in notification when saved
  * [grimshot] Avoid sending two notifications with savecopy
  * refactor(grimshot): modularize and clean up with functional helpers
  * Add color picker
  * fix(grimshot): resolve missing functional-helpers file error (#40)
- Add libinput-drag-lock-enabled-sticky.patch
* Tue Oct 29 2024 Joshua Smith <smolsheep@opensuse.org>
- Update to version 1.10:
  Features
  * All of the enhancements from wlroots 0.18.
  * Rewrite the renderer to leverage the wlroots scene-graph API,
    resulting in improved performance.
  * Add GPU reset recovery for improved robustness.
  * Add a command to use an ICC profile for an output.
  * Improved output configuration algorithm to light up more
    outputs when the GPU bandwidth is constrained.
    WLR_DRM_NO_MODIFIERS shouldn't be necessary anymore to
    workaround black screens on Intel.
  * Add support for IME popups used for CJK.
  * Add support for tearing-control-v1, to opt-in for tearing
    page-flips for gaming use-cases.
  * Add support for ext-transient-seat-v1, allowing remoting apps
    such as wayvnc to create separate temporary seats for input
    events.
  * Add support for ext-foreign-toplevel-list-v1, the new standard
    protocol to obtain information about other toplevels. This will
    eventually be used by taskbars, window switchers and
    per-toplevel screen capture.
  * Add support for xdg-shell v5 with popup repositioning and
    hiding maximize/minimize buttons in CSD.
  Changes
  * dmenu_run is no longer a dependency of the default config file.
  * The default config file now contains keybindings with pactl for
    volume adjustment, brightnessctl for brightness adjustment and
    grim for screenshots.
  * The legacy wl_drm protocol is now disabled by default
    (superseded by the standard linux-dmabuf-v1 protocol). This
    causes breakage in xorg-xwayland < 24.1.0, libva < 2.22.0 and
    amdvlk < 2024.Q4.1, and can be re-enabled manually via
  - Dlegacy-wl-drm.
  * The xwayland built-time option has been removed: Xwayland
    support is now enabled at build-time if it was enabled for
    wlroots.
* Wed Apr 10 2024 Filippo Bonazzi <filippo.bonazzi@suse.com>
- Remove versioned branding and explain why it must not be added again (bsc#1222579)
- Add sway.rpmlintrc to mask the spurious versioned branding warning
- Mask empty %%check section rpmlint warning
* Wed Feb 28 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Fix broken package by declaring the actual version of branding package of sway which
  is 0.16.0. Hopefully resolves bsc#1220496
* Mon Feb 26 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Specfile cleanup:
  * remove deprecated and obsoleted RPM symbol/macros
  * Provides should have version
* Mon Feb 26 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Add contrib files: sway-1.9-contrib.tar.gz
- Update specfile to accommodate new contrib files and contrib sub-package.
* Sun Feb 25 2024 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- Update to version 1.9
  * All of the enhancements from wlroots 0.17, including support for
    the new content-type-v1, xwayland-shell-v1, wp-fractional-scale-v1,
    security-context-v1 and cursor-shape-v1 protocols
  * Improved xdg-activation-v1 support with workspace tracking and multi-seat
  * The rendering code has been ported to the new wlroots rendering API,
    yielding better performance
  * A new config option to disable primary selection
  * A new input commands to set libinput's rotation angle and scroll button lock
  * Tablet tool buttons can now be used for floating mode resize
  * The IPC output event is now supported
  * Add support for layer-shell's on-demand keyboard interactivity
  * Default menu is now wmenu
  * KDE idle protocol is obsoleted for the standard idle-notify-v1 protocol
- Remove dee032d0a0ecd958c902b88302dc59703d703c7f.patch. Patch is included in version 1.9.
- Set wlroots version requirement to >= 0.17.0
- Update description on specfile. Sway has long since matured as a full-fledge compositor.
* Thu Oct  5 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- minor update of sway-portals.conf.
  * defaults to wlr -> falls back to gtk
* Thu Sep 28 2023 Denys Kondratenko <stdden@opensuse.org>
- fix portal config typo (see https://github.com/emersion/xdg-desktop-portal-wlr/pull/269)
* Mon Sep 25 2023 Soc Virnyl Estela <uncomfy+openbuildservice@uncomfyhalomacro.pl>
- XDP 0.18.0 requires desktop and other environments to have their own portals.conf
  by adding sway-portals.conf, we will avoid some of the problems for portals for
  * File picker -> We default to xdp-gtk since xdp-wlr does not have it.
  * For screenshots/screenshare, we use the wlr supplied interfaces
  For more information, see https://github.com/flatpak/xdg-desktop-portal/issues/1077
  and the release statement for 0.18.0
  This is a workaround for boo#1215641
* Thu Jul  6 2023 Joan Torres <joan.torres@suse.com>
- Recommend xdg-desktop-portal-wlr instead of requires.
* Tue Apr 11 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add dee032d0a0ecd958c902b88302dc59703d703c7f.patch: ipc: add
  LIBINPUT_CONFIG_ACCEL_PROFILE_CUSTOM entry.
* Sun Feb 12 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Update to 1.8.1:
  * Apply new adaptive sync value from wlr-output-management
  * warp_to_constraint_cursor_hint: Handle NULL view
  * Use correct length for strncmp comparison
  * Allow setting the font size to 0
  * input/tablet: handle focusing NULL surface
  * man: fix typo in output disable docs
  * Send wl_surface.enter for ext-session-lock surfaces
  * Fix pointer events for ext-session-lock surfaces
  * build: bump version to 1.8.1
  * focus_on_window_activation: raise if floating
  * Correct window_rect.y with hide_edge_borders
  * Clarify documentation for window_rect
* Fri Jan  6 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- For portals to work, this requires xdg-desktop-portal-wlr.
* Sun Dec 25 2022 llyyr <llyyr.public@gmail.com>
- Update to 1.8:
  New features:
  * A new bindgesture command can be used to bind actions to touchpad gestures
  * More robust and secure screen lockers via the new
    ext-session-lock-v1 protocol (supported by swaylock)
  * A new output unplug command has been added to remove virtual outputs
  * libinput's new "disable while trackpointing" setting and
    high-resolution scroll wheel events are now supported
  * xdg-activation-v1 is now used for more reliable workspace matching when
    launching new clients
  * Various improvements from wlroots' Vulkan renderer
  Changes:
  * On Linux, CAP_SYS_NICE can be set to improve scheduling
  * Manufacturer names in output identifiers might have changed
  * SUID-root is no longer supported
  * The output dpms command has been deprecated (superseded by output power)
  * The pcre dependency has been replaced with pcre2
- Remove 6484.patch, resolved upstream.
- Remove fix-upstream-gcc12-build-issue.patch, resolved upstream.
* Thu Dec  1 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Fix build: pick up a compatible verison of wlroots boo#1205766
* Sat Nov 26 2022 Andreas Stieger <andreas.stieger@gmx.de>
- Update upstream signing key and verify source signature
- https://github.com/swaywm/sway/pull/6484 6484.patch refreshed
* Mon May 16 2022 Simon Lees <sflees@suse.de>
- Fix build with gcc12
  * fix-upstream-gcc12-build-issue.patch
* Wed Feb  2 2022 Denys Kondratenko <stdden@opensuse.org>
- Restore brandig package versioning due to dependency for OpenSUSEway
  * https://github.com/openSUSE/openSUSEway/issues/54
* Fri Jan 28 2022 Michal Hrusecky <michal.hrusecky@opensuse.org>
- Prevent segfault on keyboard connection
  using upstream pull request https://github.com/swaywm/sway/pull/6484
  Patches:
  * Add 6484.patch
* Tue Jan 25 2022 Arnav Singh <opensuse@arnavion.dev>
- Update to 1.7:
  New features:
  * Add `output render_bit_depth` command to enable high-bit depth composition.
  * Tabs can now be dragged with the mouse.
  * Zero-copy direct scanout for fullscreen windows should work more reliably
    thanks to linux-dmabuf surface feedback.
  * Add support for virtual reality headsets via DRM leasing.
  * Wayland-native urgency has been implemented via
    the xdg-activation-v1 extension.
  * Add `output dpms toggle` command to easily toggle screen blanking
    from scripts.
  * Add `gaps <type> <scope> toggle <px>`, `smart_gaps inverse_outer` and
    `split none` commands.
  * Add `output modeline` command to set a full custom DRM mode when
    custom modes don't work out-of-the-box.
  * Add `client.focused_tab_title` color option.
  Changes:
  * `--my-next-gpu-wont-be-nvidia` has been removed, use `--unsupported-gpu`
    instead. The Nvidia proprietary driver remains unsupported.
  * The terminal emulator in the default config file has been changed to `foot`.
  * `swaybar` and `swaynag` are now provided by separate, optional packages.
    Make sure to install them explicitly if you use them.
  * Titlebars now have a fixed height, they no longer resize depending on
    characters used in the title.
  Patches:
  * Remove sway-1.0-include.patch since it is no longer necessary.
* Wed Dec  8 2021 Marcus Rueckert <mrueckert@suse.de>
- Add missing runtime requires for grimshot and the python tools in
  sway-contrib
* Wed Dec  8 2021 Marcus Rueckert <mrueckert@suse.de>
- according to the changes entry ffmpeg and ImageMagick were only
  needed for swaygrab and this no longer seems to be part of this
  package. drop the unused requires as well.
* Fri Sep 24 2021 Steve Kowalik <steven.kowalik@suse.com>
- Change shebang of two Python scripts to /usr/bin/python3
* Thu Jun 24 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6.1:
  * This new release adds compatibility with wlroots 0.14, and
    contains a few bug fixes.
  * See https://github.com/swaywm/sway/releases/tag/1.6.1 for details
* Thu Apr  8 2021 Michael Vetter <mvetter@suse.com>
- Update to 1.6:
  New features:
  * Input method editor (IME) improvements: better support for CJK IMEs,
    allow IMEs to work on desktop UIs (such as panels and lockscreens)
  * Smoother interactive move/resize operations
  * Allow Flatpak and snap applications to better integrate with the
    system via the xdg-foreign protocol
  * Improved i3 compatibility for commands changing the window layout
  * Add an option to hide the cursor when typing
  * Add tray icon support to systems without systemd/elogind
  * X11 clipboard reliability improvements
* Mon Mar 15 2021 Matej Cepl <mcepl@suse.com>
- Add subpackage contrib with all files from the contrib/ subdirectory.
* Wed Nov 11 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.5.1:
  * This is a bugfix release which adds support for wlroots 0.12.0.
* Thu Jul 16 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.5:
  New features:
  * Headless outputs can now be created dynamically via the create_output
    command, and can be used with WayVNC
  * Input method editors (IME) are now supported via the input-method and
    text-input protocols
  * Adaptive synchronization (aka. variable refresh rate, VRR) can be enabled
    to reduce stuttering in games
  * Support for the viewporter protocol, allowing older X11 games to work
    better and improve performance
  * Allow virtualization and remote desktop software to inhibit keyboard
    shortcuts
  * Support for the wlr-foreign-toplevel-management protocol, allowing
    custom docks and window switchers
  * For details see: https://github.com/swaywm/sway/releases/tag/1.5
- Remove 0001-Fix-compiling-with-fno-common.patch: in new release
- Remove file %%{_sysconfdir}/sway/security.d/00-defaults
* Thu Jul  2 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.5~RC2:
  * output: simplify loop over layer surfaces
  * tree/view: Make foreign-toplevel app_id fallback to class
  * transaction: Mark client resize immediately ready
  * seat: Refocus seat when wlr_drag is destroyed
  * input/pointer: correctly handle bindings for synthetic events
  * tree/view: fix smart borders with tabbed/stacked ancestor
* Thu Jun 25 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.5~RC1:
  New features:
  * Headless outputs can now be created dynamically via the create_output
    command, and can be used with WayVNC
  * Input method editors (IME) are now supported via the input-method and
    text-input protocols
  * Adaptive synchronization (aka. variable refresh rate, VRR) can be enabled
    to reduce stuttering in games
  * Support for the viewporter protocol, allowing older X11 games to work
    better and improve performance
  * Allow virtualization and remote desktop software to inhibit keyboard
    shortcuts
  * Support for the wlr-foreign-toplevel-management protocol, allowing
    custom docks and window switchers
  * For full list of changes see:
    https://github.com/swaywm/sway/releases/tag/1.5-rc1
* Mon Jun 22 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- package shouldn't require specific branding version, just a package
* Fri Jun  5 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add -fno-common patch in order to address boo#1160244
  * 0001-Fix-compiling-with-fno-common.patch
  * https://github.com/swaywm/sway/pull/4943
* Fri May 29 2020 Denis Kondratenko <denis.kondratenko@suse.com>
- Add separate branding package
* Thu May  7 2020 Michael Vetter <mvetter@suse.com>
- Remove dependency on wlc. It is long deprecated and actually
  wlroots is used.
* Wed Mar  4 2020 Max Lin <mlin@suse.com>
- Disable swaybar tray support on Leap 15.2 reflected to wlroots's
  change against Leap 15 build
* Thu Jan 23 2020 Michael Vetter <mvetter@suse.com>
- Update to 1.4:
  * Support for VNC via wayvnc. The wlroots RDP backend has been removed.
  * Partial support for the MATE panel
  * Configurable input latency controls, see max_render_time in
    sway(5) and sway-output(5)
  * Keyboard grouping (useful for certain niche keyboard designs)
  * Support for xdg-shell v6 unstable has been removed
  * The recommended terminal emulator in the default configuration
    file is now alacritty.
  * Bug fixes
* Tue Aug 27 2019 mvetter@suse.com
- Update to 1.2:
  * This release improves compatibility with i3 4.17,
    adds a small number of new features, and fixes many bugs.
  * For details see https://github.com/swaywm/sway/releases/tag/1.2
* Tue Jun  4 2019 mvetter@suse.com
- Update to 1.1.1:
  * swaybar now includes touch support - tapping to activate
    hotspots and dragging across to cycle through workspaces
  * You can now manually inhibit idle notifications (DPMS) when a
    certain criteria is active via inhibit_idle
  * Keybindings can now be unconfigured at runtime via
    unbind{sym,code,switch}
  * workspace {prev,next}_on_output --create will create the
    next workspace instead of wrapping to the start
  * Output subpixel layouts can now be explicitly configured
  * i3bar's short_text properties in the JSON protocol are
    now supported
  * swaybar now supports an "overlay" mode, which shows the bar
    on top of other windows and doesn't process input events
  * Switch devices (like lid switches) are now supported and
    can be bound to actions via bindswitch
  * swaymsg now supports a -p/--pretty option for explicitly
    enabling pretty-printing
  * More details: https://github.com/swaywm/sway/releases/tag/1.1
- Remove sway-1.0-flow.patch: upstreamed
  See https://github.com/swaywm/sway/issues/3862
- Remove sway-1.0-scdocpath.patch: scdoc pkconfig files is fixed
  See bsc#1128844
- Update sway-1.0-include.patch
* Tue Mar 12 2019 mvetter@suse.com
- Update to 1.0:
  * We have completely overhauled the codebase. Some behaviors were changed
    to match i3 behavior, in breaking ways. There are likely many bugs we
    don't know about. Your millage may vary.
  * swaygrab has been removed. For screenshots, try grim, and for video
    capture try wlstream[2]
  * This release depends on wlroots 0.5 and drops the dependency on wlc.
  * This release depends on scdoc for generating man pages, and drops
    the dependency on asciidoc.
  * Experimental Nvidia support has been deprecated since its inception,
    and has now been removed entirely. Please use nouveau and consider future
    purchases from GPU vendors that support open source. Other proprietary
    drivers are also unsupported.
  * swaylock is now distributed separately
  * swayidle, a new idle management daemon, is available separately
  * 100%% i3 compatible*
  * 100%% i3 IPC compatible*
  * 100%% i3-gaps compatible
  * 100%% i3bar compatible
  * swayidle, a daemon for managing DPMS and idle activity (e.g. automatic
    lock after a timeout), has been added - man swayidle to get started
  * swaynag, an i3-nagbar replacement, has been added, with additional
    features not supported by i3-nagbar - man swaynag to get started
  * bindsym --locked now adds keybindings which work when the screen is
    locked
  * Command blocks are now generic and work with any command
  * Window opacity can now be adjusted with the opacity command
  * border csd now enables client-side decorations explicitly
  * Atomic layout updates ensure that, when resizing windows and adjusting
    your layout, you never see an invalid frame with partially drawn clients
  * Urgency hints from Xwayland are now supported
  * Output damage tracking significantly improves CPU performance and power
    usage
  * Hardware cursors are now supported, improving performance
  * The Wayland, x11, and headless backends are now supported for end-user
    use, enabling nested and headless sway sessions
  * On-screen keyboards like virtboard[6] are now supported
  * Moving tiled windows with the mouse now behaves like the proposed i3
    feature
  * Pointer constraints allow video games and other applications to grab
    your pointer
  * Xwayland is now started only when the first X11 client is started
- Add sway-1.0-scdocpath.patch: workaround for bsc#1128844
- Add sway-1.0-include.patch: fix includes path
- Add sway-1.0-flow.patch: fix https://github.com/swaywm/sway/issues/3862
* Mon Feb 18 2019 mvetter@suse.com
- Update to 1.0 RC 2
- Remove sway-1.0-version.patch: upstreamed
* Mon Feb  4 2019 mvetter@suse.com
- Update to 1.0 RC 1
- Add sway-1.0-version.patch: We dont have git.
  See https://github.com/swaywm/sway/pull/3578
* Wed May 16 2018 rzl@l2f.inesc-id.pt
- Update to 0.15.2
  - Fix non-compliant KDE tray icons
  - Fix tray items setting and updating icons
  - Fix various tray segfaults and memory leaks
  - Fix menu placement
  - Popups no longer interfere with swaylock
  - Fixed an invalid free in workspace logic
  - Send forward/backward mouse buttons to i3bar event listeners
  - Accomodate for empty i3bar blocks
  - Gracefully handle status line errors in swaybar
  - Fix memory leaks and sadness throughout
  - Correctly handle i3bar min_width specification
  - Minor scratchpad fixes
  - Man page improvements
* Sat Dec 30 2017 adam@mizerski.pl
- cleanup spec file
  - update urls
  - fix macro usage
  - add some vesion numbers to requirements
  - add ImageMagick and ffmpeg dependency required by swaygrab
* Thu Dec 28 2017 avindra@opensuse.org
- bump to 0.15.1
  - Update to json-c 0.13
  - Documentation corrections
  - Portability fixes
  - Output scale now preserved upon reloads/hotplugs
  - Closing fullscreen windows in nested containers no longer
    crashes
  - swaygrab more gracefully handles errors
  - Fixes to some minor tray issues
  - Fix security grants for swaylock -f
  - Clear password buffer after checking it in swaylock
- partial cleanup with spec-cleaner
* Thu Nov  9 2017 aavindraa@gmail.com
- bump to 0.15.0
  Changes
  * Default wallpapers are now in /usr/share/backgrounds/sway
  * README translated into 9 more languages
  New Features
  * Improved clipboard support via swaymsg commands
  * Raspberry Pi support
  * swaylock indicator size is now configurable
  * swaybar now supports scroll events over IPC
  Bugs Fixed
  * IPC now uses nonblocking I/O
  * Tray icon theme parsing support handles getline failure
  * Correctly handle empty security policies
  * Fix zsh completion for swaylock
  * Use after free in bindsym fixed
  * Pointer accuracy bugs fixed via wlc
  * swaybar crash with invalid SNI names fixed
  * Race condition in kill command fixed
  * swaygrab no longer uses the shell to execute subprocesses
  * An issue with variables set via set $xyz was fixed
  * A number of bugs with the output command were fixed
  * Fixed move to workspaces with spaces in their names
  * Skip dotfiles when loading security configuration
  * Several issues with the scratchpad were fixed
  * swaygrab now handles permissions errors more gracefully
  * swaybar click events had an extra comma
  * FreeBSD compatability fixes
  * Fix tray when dbus is not present
* Tue Jun 20 2017 sleep_walker@opensuse.org
- bump to 0.14 rc1 prerelease
* Tue May  9 2017 sleep_walker@opensuse.org
- bump to 0.13
  Changes
  * The new_window and new_float commands are deprecated in favor of
    default_border and default_floating_border. A similar change is
    expected from i3. (@zandrmartin - #1105)
  * 444 is now an acceptable file mode for security configs (@jnsaff
  - #1117)
  * Any executable that is not owned by root will receive the
    default security policy regardless of any additional configured
    permissions (@JerziKaminsky)
  New features
  * i3-style marks are now supported (@4e554c4c - #1145 & #1155)
  * You may now configure the color of swaylock UI elements via the
    command line (@4e554c4c - #1078)
  * Floating containers may now be moved with the move command
    (@4e554c4c - #1092)
  * swaymsg pretty-prints its output if stdout is a tty (@SirCmpwn -
    [#1146])
  * [criteria] command has been implemented (@4e554c4c - #1149)
  * nvidia proprietary driver support has been implemented in wlc
    (@vially - Cloudef/wlc#245) and sway was updated as necessary
    (@SirCmpwn - #1147)
  * Security policies can now refer to symlinked executables
    (@JerziKaminsky - #1173)
  * Version string can now be specified at build time (@snoack -
    [#1194])
  Bugs fixed
  * Missing swaylock security settings were added (@SirCmpwn - 21ad45b)
  * -Werror issues on the latest gcc have been corrected (@Fale - #1086)
  * The codebase is more POSIXly correct and does not rely on
    GNUisms (@SirCmpwn - 9aed9d9)
  * Issues building against a local copy of wlc has been fixed
    (@snoack - #1115)
  * A problem with keyboard code in sway's Wayland clients was fixed
    (@zandrmartin - #1121)
  * Focus could be stolen from fullscreen windows under some
    conditions (@zandrmartin - #1126)
  * Spaces are now permitted in workspace names (@4e554c4c - #1101)
  * Issues with workspace assignment have been corrected
    (@zandrmartin - #1105)
  * Man page typos fixed (@johnchen902 - #1113)
  * Crashiness with move [next|prev] was fixed (@oranenj - #1130)
  * Regular expressions are now handled with PCRE for better i3
    compatibility (@ascent12 - #1151)
  * Dangling file descriptors on IPC client termination was fixed
    (@SirCmpwn, @ascent12 - #1153)
  * libcap is now explicitly required in our CMakeLists.txt
    (@JerziKaminsky - #1150)
  * move [to] scratchpad did not support the "to" syntax (@wasamasa
  - #1180)
  * Windows leaving the scratchpad are now sized to match i3
    behavior (@wasamasa - #1181)
  * Specifying fewer than 5 colors with client.* now matches i3
    behavior (@SirCmpwn - #1201)
* Wed May  3 2017 sleep_walker@opensuse.org
- bump to 0.13-rc1 prerelease
* Wed Apr 19 2017 sleep_walker@opensuse.org
- bump to 0.13-rc1 prerelease
* Tue Mar 14 2017 sleep_walker@opensuse.org
- bump to 0.12.1
  Bugs Fixed
    Workspace output assignment issues (@zandrmartin - #1105)
    Typo in sway(5) (@johnchen902 - #1113)
* Thu Mar  9 2017 sleep_walker@opensuse.org
- bump to 0.12
  Changes
    /etc/sway/security has been moved to
    /etc/sway/security.d/00-defaults and users are now encouraged to
    add their own security configurations as additional files in
    /etc/sway/security.d/. Maintainers of software that integrates
    with sway and require special permissions are encouraged to ship
    security configs in this directory as well (@SirCmpwn - #1080)
    If not specified at build time, LD_LIBRARY_PATH will be unset,
    rather than defaulting to /usr/lib (@Hummer12007 - #1050)
    Default backgrounds have been losslessly re-compressed and should
    reduce the package weight if enabled (@Jesin - #1032)
    Previously undocumented features (swaygrab -f and
    hide_edge_borders) are now covered by their respective manuals
    (@Hummer12007, @ametisf - #1073, #1051)
    Environment logging now occurs prior to compositor initialization,
    which helps diagnose certain kinds of problems (@SirCmpwn -
    41f7aaa)
  New Features
    New automatic layouts unique to sway have been implemented that
    behave like similar features in WMs like Awesome. See sway(5) and
    look for layout auto for details. (@willakat - #1024)
    Sway now supports gamma adjustment, which you can take advantage
    of with a patched redshift (@SirCmpwn - #1019)
    IPC features can now be secured on a per-application basis - see
    sway-security(7) (@SirCmpwn - #1080)
    focused is now available in window criteria (@Hummer12007 - #1053)
    output [left|right] now matches i3's wrapping behavior (@dkess -
    [#1048])
    XWayland window instances are now shown in title bars if necessary
    (@Hummer12007 - #1052)
    hide_edge_borders smart is now implemented, following i3 4.13
    (@ametisf - #1044)
  Bugs Fixed
    Issues compiling sway on gcc 7 have been resolved (@Fale - #1086)
    Capabilities are more carefuly handled when transitioning from
    euid 0 to a normal user, which fixes some problems on systems
    without logind (@Hummer12007 - #1043)
    xdg-shell v6 support has been fleshed out in both wlc and sway,
    which should fix things like broken right click menus on GTK apps
    (@Hummer12007 - #1070, #1055)
    Floating windows were created with the incorrect geometry, which
    has been corrected (@zandrmartin - #1075)
    Image scaling specified at the swaylock command line was ignored,
    and now works correctly (@zandrmartin - #1017)
    Inconsistencies with workspace layouts in IPC messages between i3
    and sway were corrected (@Hummer12007 - #1030)
    Workspaces with spaces in their names are now supported more
    consistently with i3 (@4e554c4c - #1011)
* Tue Feb 28 2017 sleep_walker@opensuse.org
- bump to 0.12-rc2 pre-release
* Sat Dec 31 2016 sleep_walker@opensuse.org
- bump to 0.11
  Changes
    Sway now depends on libcap on Linux
    Moving between containers now wraps according to i3 behavior
    Alpha blending is now done with CAIRO_OPERATOR_SOURCE
    bar pango_markup defaults to false, following i3 change
  - Denable-binding-event is no longer available - see sway-security(7)
    New floating windows now spawn in the center of the screen
  New Features
    Clicking titlebars now focuses that window
    Changing focus between floating containers is now supported
    Numeric character references in bar are now supported
    Pango markup in workspaces names is now supported
    Input device configuration can now enable left_handed
    Improvements to logging
    New bar colors following new i3 features - see sway-bar(5)
    New security-related features - see sway-security(7)
  Bugs Fixed
    Errors in swaybar's hidpi rendering were corrected
    Bug fixed where IPC events were emitted before IPC initialization
    Segfault during edge case on workspace switching was fixed
    An IPC tree response compatability issue was corrected
    Buggy font selection issues were fixed in swaylock
    Fixes to scale factor in text scaling
    Issue creating a sibling of a floating window fixed
    Some commands were not matched during command matching
    Indicator border no longer shown on floating windows
    An issue with for_window [] move scratchpad was fixed
    You can now move empty workspaces
    Fixes with default workspace layouts
    layout toggle split behavior fixed for tabbed/stacked layouts
    When swaylock exited, it would not focus whatever you were using
    before
* Wed Oct 26 2016 sleep_walker@opensuse.org
- bump to 0.10
  New Features
    sway now runs on FreeBSD! (thanks @yohanesu75!)
    swaymsg now pretty prints the JSON response (thanks @acrisci!)
    The application class is displayed in titlebars if the title is
    missing (thanks @thejan2009!)
    Disabling outputs at runtime might work (thanks @thejan2009!)
    i3's indicator border color feature is now supported (thanks
    @guiniol, @thejan2009!)
    Input device names in input configurations now support * (thanks
    @SirCmpwn!)
    Initial support for HiDPI was added to swaybar, swaybg, and
    swaylock (thanks @SirCmpwn, @thejan2009!)
    Moving views across an output's edge is now supported (thanks
    @mikkeloscar!)
    swaygrab can now screenshot the focused container via -f (thanks
    @zandrmartin!)
  Bugs Fixed
    A security issue was fixed - you are affected if you have users on
    your system that use sway but do not have root access - details in
    [#884] (thanks @Fale!)
    A number of changes were made to IPC for better i3 compatability
    (thanks @acrisci, @zandrmartin!)
    An uninitialized variable fixed the default config for wrap_scroll
    (thanks @minus7!)
    Color parsing previously could cause values to clamp and lose
    information (thanks @progandy!)
    workspace back_and_forth and workspace_auto_back_and_forth had
    issues getting along (thanks @thejan2009!)
    Weirdness in edge cases with moving windows was fixed (thanks
    @Hummer12007!)
    Edge case in workspace handling during view creation was fixed
    (thanks @thejan2009!)
    A problem with move container to workspace was fixed (thanks
    @thejan2009!)
    Null pointer dereference during config load edge case was fixed
    (thanks @kb100!)
    The behavior of hide_edge_borders was fixed (thanks
    @lukaslihotzki!)
    Fullscreen windows previously had input priority over swaylock
    (thanks @SirCmpwn!)
    The behavior of pango markup on swaybar was fixed (thanks
    @zandrmartin!)
    swaybar previously couldn't switch between workspaces with spaces
    in their names (thanks @thejan2009!)
    swaybars could be loaded before all outputs were loaded, which
    could cause a segfault (thanks @RyanDwyer!)
    An IPC-related segfault during initialization was fixed (thanks
    @gutsoo!)
    Possible use-after-free in focus handling was fixed (thanks
    @zandrmartin!)
  Changes
    Some improvements were made to the default config (thanks
    @mayhewj, @goetzc, @zandrmartin!)
    Some internal refactoring around focus (thanks @acrisci!)
    Some internal refactoring around commands (thanks @zandrmartin!)
    Improvements were made to man pages (thanks @minus7, @mmlb!)
    pango_markup in your bar config now defaults to false, following
    the same change in i3 (thanks @Hummer12007!)
* Wed Oct  5 2016 sleep_walker@opensuse.org
- bump to 0.10-rc2
* Tue Sep 27 2016 sleep_walker@opensuse.org
- bump to 0.10-rc1
  check GIT commit messages for complete changelog
* Sun Jul 31 2016 sleep_walker@opensuse.org
- bump to 0.9
  New Features
    Experimental HiDPI support. Add scale 2 to your output line, see
    sway(5) for details and #797 for status (thanks @SirCmpwn and the
    wlc team!)
    Mouse support for swaybar (thanks @deklov!)
    New bar command wrap_scroll [yes|no] allows you to wrap when
    scrolling through workspaces with swaybar (thanks @SirCmpwn!)
    Windows that have a parent (i.e. most dialog windows) are now
    floated by default (thanks @SirCmpwn!)
    The IPC get_tree message is implemented (thanks @zandrmartin!)
    IPC window events have been implemented (thanks @Hummer12007!)
    Swaylock has a new -f option which will cause it to fork into the
    background (which matches i3lock's behavior) (thanks
    @SethBarberee!)
    The focus child i3 command has been implemented (thanks @acrisci!)
    Spawned processes now keep track of what workspace was active when
    they were started and will open subsequent windows there (thanks
    @zandrmartin!)
    Backgrounds can now be a solid color (thanks @zandrmartin!)
  Bugs Fixed
    A crash could occur in tabbed/stacking parent checks (thanks
    @Hummer12007!)
    Strange split{h|v} regressions were corrected (thanks
    @Hummer12007!)
    A corner case with tacked/stabbed containers as the default layout
    was fixed (thanks @thejan2009!)
    An edge case that could cause crashes when destroying workspaces
    was fixed (thanks @Hummer12007!)
    An error with the move position command was fixed (thanks
    @deklov!)
    Event bitmasks in the IPC server were incorrect and fixed (thanks
    @Hummer12007!)
    A regression and a bug in hide_edge_borders was fixed (thanks
    @zandrmartin and @thejan2009!)
    A bug with smart_gaps and outer gaps 0 was fixed (thanks
    @thejan2009!)
    floating_scroll events are no longer passed through to windows
    (thanks @thejan2009!)
    IPC command results are encapsulated in a JSON array to match i3
    behavior (thanks @acrisci!)
    focus parent no longer attempts to focus anything higher than a
    workspace (thanks @acrisci!)
    Window titles are now rendered appropriately when a parent of them
    is focused (thanks @acrisci!)
    Windows spawned on empty workspaces with the tabbed/stacked
    layouts could spawn with 0x0 geometry (thanks @thejan2009!)
    Killing a container now kills all of its children (thanks
    @thejan2009!)
    Edge cases with various border styles in tabbed/stacked were fixed
    (thanks @thejan2009!)
    Edge cases with tabbed/stacked layouts on layout switch were fixed
    (thanks @thejan2009!)
    Focus handling was improved to better handle cases when containers
    were being focused (thanks @acrisci!)
    Floating containers cache their size when being fullscreened and
    return to that size when unfullscreened (thanks @zandrmartin!)
  Changes
    The mouse cursor used over the wallpaper and bar can be customized
    with the SWAY_CURSOR_THEME and SWAY_CURSOR_SIZE environment
    variables (thanks @SirCmpwn!)
    SIGSERV and SIGABORT are no longer handled. We just let the core
    dump happen, which we'll be asking you to upload for us when
    reporting crashes (thanks @SirCmpwn!)
    Title bars of containers are now constructed based on their
    children's app IDs instead of their titles, which matches i3
    behavior more or less (thanks @thejan2009!)
    Log messages are now timestamped (thanks @acrisci!)
    Some performance improvements in the form of more timely window
    arrangement calls were made (thanks @zandrmartin!)
    Various improvements to the documentation (thanks lots of people)
* Mon Jun 20 2016 sleep_walker@opensuse.org
- bump to 0.8
  New Features
    You can clear the password buffer in swaylock with ESC or C-u
    swaylock now supports the --no-unlock-indicator option
    Floating views now have sane (and configurable) minimum and
    maximum sizes
    Escaping line breaks in your configuration file is now supported
    Using exec to launch applications now opens their windows on the
    workspace they were exec-d on (thanks @zandrmartin!) - note: does
    not presently work with x clients
  Bugs Fixed
    When hotplugging an output, workspace assignment rules are
    re-enforced
    Spaces in quoted output command arguments now behave properly
    Changing focus into an output with a fullscreen view now behaves
    correctly
    A number of IPC-related memory leaks were closed
    A segfault was fixed involving an edge case of include with *
    Your wallpaper is now updated on config file reload
    hide_edge_borders with smart_gaps enabled now behaves correctly
  Changes
    Creating a variable via set without the leading $ is automatically
    corrected to include it
    When hotplugging outputs, workspaces are now sorted correctly and
    maintain their sort order on replug
    The documentation was corrected to remove the (currently
    unimplemented) left/right bar placement options
    Missing layout modes (stacking and tabbed) were documented in
    sway(5)
    The assign command was documented in sway(5)
    Several other small improvements to the man pages were made
- drop 0001-Match-definition-with-declaration.patch
* Mon May 23 2016 sleep_walker@opensuse.org
- bump to 0.7
  New Features
    Bind actions to $mod+[scroll whell] via floating_scroll (thanks @Hummer12007!)
    Set the acceleration profile for input devices via accel_profile (thanks @tajjada!)
  Bugs Fixed
    Window titles are updated when the application requests it (thanks @mikkeloscar!)
    Screwing with the border settings on tabbed and stacking layouts caused breakage (thanks @tajjada!)
    Several memory leaks, double frees, etc were fixed (thanks @neosilky!)
    Several double closes, buffer overflows, etc were fixed (thanks @1ace!)
    Many other small bugs were fixed (thanks @mikkeloscar, @xerpi, @1ace!)
    Some typos were found and fixed in the man pages (thanks @cyberhuman!)
  Changes
    The hardcoded $mod+scroll actions introduced in sway 0.4 has been removed.
    You can now use a relative path to your wallpaper (thanks @Hummer12007!)
    ZSH completions are no longer included in the default build
    Cairo and Pango are now required dependencies (previously they
    were only required if you wanted swaybg or swaybar support)
- match definition with declaration using patch
  0001-Match-definition-with-declaration.patch
* Sun May  1 2016 sleep_walker@opensuse.org
- bump to release 0.6
  New Features
    Tabbed & stacking layouts
    Pango markup on swaybar
  Bugs Fixed
    bindcode was incorrectly implemented and was corrected
    Window borders no longer render under transparent fullscreen windows
    swaylock's PAM configuration has been fixed on Debian derivatives
    A double free issue was discovered and fixed
  Changes
    Some improvements were made to the build process
    Several clang warnings were squelched
    Small fixes were made to the default config
- dropping patches
    CMake-fixes.patch
    mark_static.patch
    respect_flags.patch
* Thu Apr 28 2016 sleep_walker@opensuse.org
- with huge help of scarabeus_iv all the workarounds were removed and
  fixes were already accepted by upstream - until next release we'll
  live with:
    CMake-fixes.patch
    mark_static.patch
    respect_flags.patch
* Thu Apr 28 2016 sleep_walker@opensuse.org
- Xwayland was split from xorg-x11-server into separate subpackage
  xorg-x11-server-wayland - let's fix this requirement
* Thu Apr 21 2016 sleep_walker@opensuse.org
- bump to release 0.5
- do not mark zsh completion scripts as configuration
- add LICENSE README.md CONTRIBUTING.md HACKING.md to the package
* Sat Apr 16 2016 sleep_walker@opensuse.org
- new git snapshot (2016-04-11, 9412dc7)
  tagged as version 0.4
  for complete list of changes check GIT log
* Sat Feb 27 2016 sleep_walker@opensuse.org
- new git snapshot (2016-02-27, e19e32c)
  fixed some crashes
  Removed p as a valid CLI option
  IPC and view related improvements
* Thu Feb  4 2016 sleep_walker@opensuse.org
- new git snapshot (2016-01-29, 6793648)
  swaylock and swaybar improvements and fixes
  zsh completion for swaylock
* Wed Jan 20 2016 sleep_walker@opensuse.org
- new git snapshot (2016-01-19, a6b1998)
  libinput related improvements
  IPC related improvements
  implemented bindsym --release
- add zsh completion files
- cheat also with path to libinput.h
* Wed Jan  6 2016 sleep_walker@opensuse.org
- new git snapshot (2015-12-06, 8f5de70)
  layout related work
  swaybar development
  ...
* Fri Dec 18 2015 sleep_walker@opensuse.org
- remove %%cmake macro
  - DBUILD_SHARED_LIBS:BOOL=ON is causing linker problems
* Thu Dec 17 2015 sleep_walker@opensuse.org
- new git snapshot (2015-12-17, 89341c0)
  (automatically triggered)
- add pam-devel among dependencies
* Thu Dec 17 2015 sleep_walker@opensuse.org
- remove cmake-fix.patch and generate_coredump.patch
- add wayland-util.h path into CPATH as well
- add gdk-pixbuf among dependencies
* Thu Dec 17 2015 sleep_walker@opensuse.org
- new git snapshot (2015-12-16, 3a82936)
  swaybg related stuff
  swaybar related initial stuff
  fix some crash
* Thu Nov 26 2015 sleep_walker@opensuse.org
- new git snapshot (2015-11-25, 206606b)
  Call swaybg without invoking a shell
  swaybg: implement scaling modes
  swaybg: check for exact number of arguments
  criteria: Code formatting.
  config: print line number
  config: remove trailing whitespace
- workaround upstream problem with header configuration using CPATH
* Mon Nov 23 2015 sleep_walker@opensuse.org
- new git snapshot (2015-11-22, cb11364)
  output related improvements
  handling background
  much more
* Tue Nov 17 2015 sleep_walker@opensuse.org
- drop generate_coredump.patch
* Tue Nov 17 2015 sleep_walker@opensuse.org
- new git snapshot (2015-11-16, 0120256)
  Track pid of child process from exec
  output: Support multiple adjacent outputs.
  cmd_output: Replace existing config if called multiple times.
  Update README
  HACKING.md: Add code overview section.
  We somewhat more wlc_point now
  We wlc_point now
  Check the client_setup() return value
  ipc: Store socketname in SWAYSOCK. Fixes `--get-socketpath`.
  New screenshot for README
  Clean up some things better in wayland clients
  Revert "Try ~/.i3/config earlier than /etc/sway/config"
  Try ~/.i3/config earlier than /etc/sway/config
  ipc: Put socket into proper user runtime dir.
  Fix man page installs
  Clean up CMake stuff
  cmake: run git in the source directory
  common: create a static library
  cmake: clean up installation rules
  cmake: clean up definition settings
  cmake: manipulate CMAKE_MODULE_PATH as a list
  cmake: set the output directory once
  cmake: simplify manpage generation
  cmake: use string(TIMESTAMP)
  cmake: bump requirement to 3.1.0
  We don't need to implement strdup
  Further refinement of wayland client support
  Start fleshing out wayland client implementation
  Start working on IPC for get_pixels
  Add new swaybg dependencies
  Add swaybg executable
  Add new dependencies for wayland clients
  Fix gaps for views being incorrect
  Fix some IPC issues
  Add file and line number to log in Debug build
  Add some documentation comments
  Include header declaring ipc_event_workpace(2)
  Learn "gaps edge_gaps <on|off|toggle>".
  commands: gaps: Re-arrange windows after changing default gaps.
  commands: gaps: Always apply default gaps config.
  commands: gaps: Accept zero value.
  sway.5.txt: Clarify gaps documentation.
  commands: gaps: Refactor, expected_syntax.
  commands: Learn 'move workspace to output <direction|name>'.
  commands: Learn 'move <container|window> to output <direction|name>'.
* Mon Nov  2 2015 sleep_walker@opensuse.org
- new git snapshot (2015-11-02, 0833fa0)
  - fix ipc_event_workspace() related crashes
* Sun Nov  1 2015 sleep_walker@opensuse.org
- generate_coredump.patch: generate coredump instead of graceful
  termination
* Fri Oct 30 2015 sleep_walker@opensuse.org
- Add -DCMAKE_BUILD_TYPE=Debug to obtain more information about
  problems
* Thu Oct 29 2015 sleep_walker@opensuse.org
- new git snapshot (2015-10-28, 239f4bd)
* Tue Oct 27 2015 sleep_walker@opensuse.org
- new git snapshot (eb847a1, 2015-10-25)
  - fixes & features
* Thu Oct  8 2015 sleep_walker@opensuse.org
- new git snapshot
  - fixes child process handling correctly (this time for sure :)
* Thu Oct  8 2015 sleep_walker@opensuse.org
- new git snapshot
  - fixes ending zombie processes correctly
* Sun Oct  4 2015 sleep_walker@opensuse.org
- xkbcommon-fix.patch and install-path.patch were accepted by upstream
  and so they can be dropped from here
* Wed Sep 30 2015 sleep_walker@opensuse.org
- xkbcommon-fix.patch (use xkbcommon header include path)
- install-path.patch (don't assume we're building from the same path)
* Fri Aug 21 2015 sleep_walker@suse.cz
- let there be sway!
